==> windmill_device-1.0.0.10-py3-none-any.whl: devicev1/client/device_client.py <==
# -*- coding: utf-8 -*-
"""
Copyright(C) 2024 baidu, Inc. All Rights Reserved

# @Time : 2024/12/9 15:58
# @Author : leibin01
# @Email: leibin01@baidu.com
"""
import json
from baidubce.http import http_methods
from baidubce.http import http_content_types
from bceinternalsdk.client.bce_internal_client import BceInternalClient
from .device_api import UpdateDeviceRequest, InvokeMethodHTTPRequest, ListDeviceRequest


class DeviceClient(BceInternalClient):
    """
    A client class for interacting with the windmill device service.
    """

    def list_device(
            self,
            req: ListDeviceRequest):
        """
        List devices in a device hub.

        Args:
            req (ListDeviceRequest): 列出设备请求
        Returns:
            HTTP request response
        """

        return self._send_request(
            http_method=http_methods.GET,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + req.workspace_id
                + "/devicehubs/"
                + req.device_hub_name
                + "/devices",
                encoding="utf-8",
            ),
            params=req.model_dump(by_alias=True, exclude_defaults=True),
        )

    def update_device(
            self,
            request: UpdateDeviceRequest):
        """
        Update a device.

        Args:
            request (UpdateDeviceRequest): 更新设备请求
        Returns:
             HTTP request response
        """

        return self._send_request(
            http_method=http_methods.PUT,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + request.workspace_id
                + "/devicehubs/"
                + request.device_hub_name
                + "/devices/"
                + request.device_name,
                encoding="utf-8",
            ),
            body=request.model_dump_json(by_alias=True, exclude_defaults=True),
        )

    def invoke_method_http(
            self,
            request: InvokeMethodHTTPRequest):
        """
        Invoke a method via HTTP.
        Args:
            request (InvokeMethodHTTPRequest): 调用方法HTTP请求
        Returns:
            HTTP request response
        """

        return self._send_request(
            http_method=http_methods.POST,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + request.workspace_id
                + "/devicehubs/"
                + request.device_hub_name
                + "/devices/"
                + request.device_name
                + "/invokemethods/http/"
                + request.uri,
                encoding="utf-8",
            ),
            body=request.model_dump_json(by_alias=True, exclude_defaults=True),
        )

==> windmill_device-1.0.0.12-py3-none-any.whl: devicev1/client/device_client.py <==
# -*- coding: utf-8 -*-
"""
Copyright(C) 2024 baidu, Inc. All Rights Reserved

# @Time : 2024/12/9 15:58
# @Author : leibin01
# @Email: leibin01@baidu.com
"""
import json
from baidubce.http import http_methods
from baidubce.http import http_content_types
from bceinternalsdk.client.bce_internal_client import BceInternalClient
from device_api import UpdateDeviceRequest, InvokeMethodHTTPRequest, ListDeviceRequest


class DeviceClient(BceInternalClient):
    """
    A client class for interacting with the windmill device service.
    """

    def list_device(
            self,
            req: ListDeviceRequest):
        """
        List devices in a device hub.

        Args:
            req (ListDeviceRequest): 列出设备请求
        Returns:
            HTTP request response
        """

        return self._send_request(
            http_method=http_methods.GET,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + req.workspace_id
                + "/devicehubs/"
                + req.device_hub_name
                + "/devices",
                encoding="utf-8",
            ),
            body=req.model_dump(by_alias=True, exclude_defaults=True),
        )

    def update_device(
            self,
            request: UpdateDeviceRequest):
        """
        Update a device.

        Args:
            request (UpdateDeviceRequest): 更新设备请求
        Returns:
             HTTP request response
        """

        return self._send_request(
            http_method=http_methods.PUT,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + request.workspace_id
                + "/devicehubs/"
                + request.device_hub_name
                + "/devices/"
                + request.device_name,
                encoding="utf-8",
            ),
            body=request.model_dump_json(by_alias=True, exclude_defaults=True),
        )

    def invoke_method_http(
            self,
            request: InvokeMethodHTTPRequest):
        """
        Invoke a method via HTTP.
        Args:
            request (InvokeMethodHTTPRequest): 调用方法HTTP请求
        Returns:
            HTTP request response
        """

        return self._send_request(
            http_method=http_methods.POST,
            headers={b"Content-Type": http_content_types.JSON},
            path=bytes(
                "/v1/workspaces/"
                + request.workspace_id
                + "/devicehubs/"
                + request.device_hub_name
                + "/devices/"
                + request.device_name
                + "/invokemethods/http/"
                + request.uri,
                encoding="utf-8",
            ),
            body=request.model_dump_json(by_alias=True, exclude_defaults=True),
        )
